function opts = getLLROptimizationParams

    % Maximum number of majorization-minimization (MM) iterations, i.e. the
    % number of iterations in the outer optimization loop of multi-channel
    % super-resolution (should be between 5 and 15).
    opts.maxMMIter = 10;
    
    % Maximum number of scaled conjugate gradients (SCG) iterations in the
    % inner optimization loop used for image reconstruction (should be
    % between 3 and 10).
    opts.maxSCGIter = 10;
        
    % Termination tolerance for max(x(t) - x(t-1)) for the estimate of the
    % high-resolution image over the iterations (should be between 1e-3 and
    % 1e-2).
    opts.terminationTol = 1e-3;
    
    % Sparsity parameter used for weighted bilateral total variation used
    % as the intra-channel prior. Can be a scalar (-> use the same
    % parameter for each channel) or a vector (-> use different parameters
    % for the channels).
    % (should be ~0.5 and can be selected in [0; 1]).
    opts.sparsityParameter = 0.5;
    
    opts.intraChannelPrior = {};
    
    % Inter-channel regularization weights given as C x C matrix for C
    % image channels, where the element at position (i,j) denotes the
    % regularization weight for the correponding pair of channels. If this
    % parameter is a scalar value, the same weight is used for all pairs of
    % channels.
    opts.interChannelWeights = 1e-3;
   
    % Regularization weights for the LLR hyperparameters (filter
    % coefficients) given as C x C matrix for C image channels, where the
    % element at position (i,j) denotes the weight for the corresponding
    % pair of channels. If this parameter is a scalar value, the same 
    % weight is used for all pairs of channels.
    opts.llrHyperparameterWeights = 1e-4;
    
    % Image patch radius used for LLR. If r denots the radius, quadratic
    % patches of size (2r + 1) x (2r + 1) are used (should be 1 ... 3).
    opts.llrPatchRadius = 2;
    
    % Resampling factor for the computation of the LLR parameters by means
    % of fast guided filtering. If the resampling factor is set to 1
    % conventional guided filtering is used (should be between 1 and 8).
    opts.llrSamplingFactor = 1;
    
    % Flag to indicate weather the adaptive LLR model based on confidence
    % weighting to implement an M-estimator or simple least squares 
    % regression should be used.
    opts.adaptiveLLR = true;